==> ejc-supbid-api-3.0.1-20220126.031941-136-sources.jar: com/ejianc/business/supbid/rent/vo/RentSchemeVO.java <==
package com.ejianc.business.supbid.rent.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 设备租赁方案实体
 * 
 * @author generator
 * 
 */
@ApiModel("设备租赁方案实体")
public class RentSchemeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private Long noticeId;
    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("方案名称")
    private String schemeName;
    @ApiModelProperty("报价总额")
    private BigDecimal money;
    @ApiModelProperty("报价总额(含税)")
    private BigDecimal moneyTax;
    

    /**
     * 主表主键
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案名称
     */
    public String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    /**
     * 报价总额
     */
    public BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    
}

==> ejc-supbid-api-3.0.1-20231027.091539-236-sources.jar: com/ejianc/business/supbid/rent/vo/RentSchemeVO.java <==
package com.ejianc.business.supbid.rent.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.supbid.rent.vo.RentSchemeDetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 设备租赁方案实体
 * 
 * @author generator
 * 
 */
@ApiModel("设备租赁方案实体")
public class RentSchemeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private Long noticeId;
    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("方案名称")
    private String schemeName;
    @ApiModelProperty("报价总额")
    private BigDecimal money;
    @ApiModelProperty("报价总额(含税)")
    private BigDecimal moneyTax;

    @ApiModelProperty("设备租赁报价明细")
    private List<RentSchemeDetailVO> rentSchemeDetailList = new ArrayList<>();
    /**
     * 主表主键
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案名称
     */
    public String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    /**
     * 报价总额
     */
    public BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }


    public List<RentSchemeDetailVO> getRentSchemeDetailList() {
        return rentSchemeDetailList;
    }

    public void setRentSchemeDetailList(List<RentSchemeDetailVO> rentSchemeDetailList) {
        this.rentSchemeDetailList = rentSchemeDetailList;
    }
}
